Module jpeg

Module jpeg 

DCTDecode filter — JPEG decompression.

Maps to upstream PDFium’s core/fxcodec/jpeg/jpegmodule.h/cpp. Uses zune-jpeg (pure Rust) instead of libjpeg-turbo.

Structs

JpegInfo
Information extracted from JPEG markers before decoding.

Functions

decode
Decode JPEG (DCT) compressed data.
decode_with_recovery
Decode JPEG data with automatic recovery for known bad headers.
load_info
Upstream-aligned alias for probe_jpeg_info(). Corresponds to JpegModule::LoadInfo().
probe_jpeg_info
Probe JPEG data to extract image information without fully decoding.
try_patch_invalid_height
Detect and attempt to fix JPEG data with a known bad header where height is 0xFFFF.