pub struct DctScanlineDecoder { /* private fields */ }Expand description
Scanline decoder for DCTDecode (JPEG) data.
Decodes the full JPEG internally on construction, then yields one scanline at a time based on the decoded pixel stride.
Implementations
Sourceimpl DctScanlineDecoder
impl DctScanlineDecoder