DctStreamingDecoder

Struct DctStreamingDecoder 

pub struct DctStreamingDecoder { /* private fields */ }
Streaming decoder for DCTDecode (JPEG).

Since JPEG requires the full input to decode, this accumulates bytes and performs the actual decode in finish().

Implementations

Source

impl DctStreamingDecoder

pub fn new() -> Self

Create a new streaming DCT decoder.