DCTDecode filter — JPEG decompression.
Maps to upstream PDFium’s core/fxcodec/jpeg/jpegmodule.h/cpp.
Uses zune-jpeg (pure Rust) instead of libjpeg-turbo.
Structs
- Jpeg
Info - Information extracted from JPEG markers before decoding.
Functions
- decode
- Decode JPEG (DCT) compressed data.
- decode_
with_ recovery - Decode JPEG data with automatic recovery for known bad headers.
- load_
info - Upstream-aligned alias for
probe_jpeg_info(). Corresponds toJpegModule::LoadInfo(). - probe_
jpeg_ info - Probe JPEG data to extract image information without fully decoding.
- try_
patch_ invalid_ height - Detect and attempt to fix JPEG data with a known bad header where height is 0xFFFF.